==> rsmooth-0.3.0.crate: rsmooth-0.3.0/TODO.md <==
# TODO's

- [x] Empty `template` field behavior. (v.0.2.0)
- [x] Tera Templating(v.0.2.0)
	- [x] Debug context (-)
	- [x] Rename header fields (v.0.2.0)
	- [x] Update documentation (v.0.2.0)
	- [x] Allow more complex template_context values (v.0.2.0)
	- [x] Update documentation (v.0.2.0)
- [ ] Documentation
	- [x] Finish `README.md` (v.0.2.0)
	- [x] Document available environment variables (v.0.2.1)
	- [ ] Example header with all options
	- [ ] Logo
	- [ ] Document installation
	- [ ] Document Library
	- [ ] Link to API
- [x] Bibliography
	- [x] Fix relative imports in front matter header for bibliography(v.0.2.1)
	- [x] Fix depreciated citeproc filter (v.0.2.1)
	- [x] Path to Citation Style file (v.0.2.1)
	- [x] Bibliography stuff works (v.0.2.1)
	- [x] Documentation done (v.0.2.1)
- [x] Example file functionality
	- [x] Implement (v.0.2.1)
	- [x] Correct location for output path in CLI (v.0.2.1)
	- [x] Fix did you mean example command bug in CLI (v.0.2.1)
	- [x] Documentation done (v.0.2.1)
- [-] Filters (discarded)
	- [-] Implementation done (discarded)
	- [-] Activate as list in header (discarded)
	- [-] Template filter activation via list (discarded)
	- [-] Implement path expansion (discarded)
	- [-] Documentation done (discarded)
- [x] Relative paths in documents
	- [x] Fix the handling for relative resource links in documents (v.0.2.1)
	- [x] Remove unused expand_paths filter (v.0.2.1)
- [ ] Filters/Split description
	- [x] Move template module to tera module in root (v.0.2.1)
	- [ ] Implement embedded Lua filter structure
	- [ ] Implement as filter
	- [ ] Documentation done
- [ ] Release binaries
	- [ ] Linux x86_64
	- [ ] Apple x86_64
	- [ ] Apple aarch64 (M1)
	- [ ] Windows x86_64
	- [ ] deb Package
	- [ ] rpm Package
- [x] Other
	- [x] metadata.rs: Give Methods meaningful names (v.0.2.1)
	- [-] File ending for temporary file (discarded)

- [x] Reveal.js integration (v.0.3.0)
- [ ] Get default documents
- [ ] Libre Office/Word output
	- [x] odt Export (v.0.3.0)
	- [x] odt Reference file (v.0.3.0)
	- [ ] odt Template file
	- [x] docx Export (v.0.3.0)
	- [x] docx Reference file (v.0.3.0)
	- [x] error when wrong reference file type (v.0.3.0)
	- [ ] error when docx gets template
	- [x] pdf export via OpenOffice (v.0.3.0)
- [x] Document output formats (v.0.3.0)
- [ ] NeoVim Plugin
- [ ] metadata.rs
	- [ ] Remove Header/Metadata duplicate
- [ ] Load templates from URL's
- [ ] Wordcount
- [ ] Download the revealjs dependencies
- [ ] Install via cargo
- [ ] Pass data to tera context via path to YAML file

Version 0.3 adds new output formats:

- Export documents to odt
- Export documents to docx
- Set a reference file for odt and docx files
- Export odt files and convert them to a pdf using LibreOffice
- Export slide shows using reveal.js

==> rsmooth-0.3.1.crate: rsmooth-0.3.1/TODO.md <==
# TODO's

- [x] Empty `template` field behavior. (v.0.2.0)
- [x] Tera Templating(v.0.2.0)
	- [x] Debug context (-)
	- [x] Rename header fields (v.0.2.0)
	- [x] Update documentation (v.0.2.0)
	- [x] Allow more complex template_context values (v.0.2.0)
	- [x] Update documentation (v.0.2.0)
- [ ] Documentation
	- [x] Finish `README.md` (v.0.2.0)
	- [x] Document available environment variables (v.0.2.1)
	- [ ] Example header with all options
	- [ ] Logo
	- [ ] Document installation
	- [ ] Document Library
	- [ ] Link to API
- [x] Bibliography
	- [x] Fix relative imports in front matter header for bibliography(v.0.2.1)
	- [x] Fix depreciated citeproc filter (v.0.2.1)
	- [x] Path to Citation Style file (v.0.2.1)
	- [x] Bibliography stuff works (v.0.2.1)
	- [x] Documentation done (v.0.2.1)
- [x] Example file functionality
	- [x] Implement (v.0.2.1)
	- [x] Correct location for output path in CLI (v.0.2.1)
	- [x] Fix did you mean example command bug in CLI (v.0.2.1)
	- [x] Documentation done (v.0.2.1)
- [-] Filters (discarded)
	- [-] Implementation done (discarded)
	- [-] Activate as list in header (discarded)
	- [-] Template filter activation via list (discarded)
	- [-] Implement path expansion (discarded)
	- [-] Documentation done (discarded)
- [x] Relative paths in documents
	- [x] Fix the handling for relative resource links in documents (v.0.2.1)
	- [x] Remove unused expand_paths filter (v.0.2.1)
- [ ] Filters/Split description
	- [x] Move template module to tera module in root (v.0.2.1)
	- [ ] Implement embedded Lua filter structure
	- [ ] Implement as filter
	- [ ] Documentation done
- [ ] Release binaries
	- [ ] Linux x86_64
	- [ ] Apple x86_64
	- [ ] Apple aarch64 (M1)
	- [ ] Windows x86_64
	- [ ] deb Package
	- [ ] rpm Package
- [x] Other
	- [x] metadata.rs: Give Methods meaningful names (v.0.2.1)
	- [-] File ending for temporary file (discarded)

- [x] Reveal.js integration (v.0.3.0)
- [ ] Get default documents
- [ ] Libre Office/Word output
	- [x] odt Export (v.0.3.0)
	- [x] odt Reference file (v.0.3.0)
	- [ ] odt Template file
	- [x] docx Export (v.0.3.0)
	- [x] docx Reference file (v.0.3.0)
	- [x] error when wrong reference file type (v.0.3.0)
	- [ ] error when docx gets template
	- [x] pdf export via OpenOffice (v.0.3.0)
- [x] Document output formats (v.0.3.0)
- [ ] NeoVim Plugin
- [ ] metadata.rs
	- [ ] Remove Header/Metadata duplicate
- [ ] Load templates from URL's
- [ ] Wordcount
- [ ] Download the revealjs dependencies
- [x] Install via cargo
- [ ] Pass data to tera context via path to YAML file
